==> tencentcloud_sdk_python-3.0.1433-py2.py3-none-any.whl: tencentcloud/lkeap/v20240522/errorcodes.py <==
# -*- coding: utf8 -*-
# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


# 操作失败。
FAILEDOPERATION = 'FailedOperation'

# FailedOperation.DownLoadError
FAILEDOPERATION_DOWNLOADERROR = 'FailedOperation.DownLoadError'

# 引擎层内部错误；
FAILEDOPERATION_ENGINESERVERERROR = 'FailedOperation.EngineServerError'

# FailedOperation.FileDecodeFailed
FAILEDOPERATION_FILEDECODEFAILED = 'FailedOperation.FileDecodeFailed'

# FailedOperation.ImageDecodeFailed
FAILEDOPERATION_IMAGEDECODEFAILED = 'FailedOperation.ImageDecodeFailed'

# 暂不支持解析该文件
FAILEDOPERATION_NONSUPPORTPARSE = 'FailedOperation.NonsupportParse'

# FailedOperation.OcrFailed
FAILEDOPERATION_OCRFAILED = 'FailedOperation.OcrFailed'

# 内部未知错误。
FAILEDOPERATION_UNKNOWERROR = 'FailedOperation.UnKnowError'

# FailedOperation.UnKnowFileTypeError
FAILEDOPERATION_UNKNOWFILETYPEERROR = 'FailedOperation.UnKnowFileTypeError'

# 服务未开通。
FAILEDOPERATION_UNOPENERROR = 'FailedOperation.UnOpenError'

# 生成识别结果文件访问url失败，请稍后重试。
FAILEDOPERATION_UPLOADRESULTFILEFAILED = 'FailedOperation.UploadResultFileFailed'

# 内部错误。
INTERNALERROR = 'InternalError'

# 参数错误。
INVALIDPARAMETER = 'InvalidParameter'

# 参数值错误。
INVALIDPARAMETERVALUE_INVALIDPARAMETERVALUELIMIT = 'InvalidParameterValue.InvalidParameterValueLimit'

# 超过最大文件页数限制
LIMITEXCEEDED_EXCEEDEDMAXPAGESERROR = 'LimitExceeded.ExceededMaxPagesError'

# 文件太大
LIMITEXCEEDED_TOOLARGEFILEERROR = 'LimitExceeded.TooLargeFileError'

# 请求的次数超过了频率限制。
REQUESTLIMITEXCEEDED = 'RequestLimitExceeded'

# 帐号已欠费。
RESOURCEUNAVAILABLE_INARREARS = 'ResourceUnavailable.InArrears'

# 账号资源包耗尽。
RESOURCEUNAVAILABLE_RESOURCEPACKAGERUNOUT = 'ResourceUnavailable.ResourcePackageRunOut'

# 计费状态异常。
RESOURCESSOLDOUT_CHARGESTATUSEXCEPTION = 'ResourcesSoldOut.ChargeStatusException'

==> tencentcloud_sdk_python-3.0.1471-py2.py3-none-any.whl: tencentcloud/lkeap/v20240522/errorcodes.py <==
# -*- coding: utf8 -*-
# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


# 操作失败。
FAILEDOPERATION = 'FailedOperation'

# 引擎层内部错误；
FAILEDOPERATION_ENGINESERVERERROR = 'FailedOperation.EngineServerError'

# 解析失败
FAILEDOPERATION_FILEPARSEERROR = 'FailedOperation.FileParseError'

# 文档解析超时
FAILEDOPERATION_FILEPARSETIMEOUT = 'FailedOperation.FileParseTimeout'

# 内部错误
FAILEDOPERATION_INTERNALERROR = 'FailedOperation.InternalError'

# 暂不支持解析该文件
FAILEDOPERATION_NONSUPPORTPARSE = 'FailedOperation.NonsupportParse'

# FailedOperation.OcrFailed
FAILEDOPERATION_OCRFAILED = 'FailedOperation.OcrFailed'

# 内部未知错误。
FAILEDOPERATION_UNKNOWERROR = 'FailedOperation.UnKnowError'

# 服务未开通。
FAILEDOPERATION_UNOPENERROR = 'FailedOperation.UnOpenError'

# 生成识别结果文件访问url失败，请稍后重试。
FAILEDOPERATION_UPLOADRESULTFILEFAILED = 'FailedOperation.UploadResultFileFailed'

# 内部错误。
INTERNALERROR = 'InternalError'

# 参数错误。
INVALIDPARAMETER = 'InvalidParameter'

# 文件url链接不正确
INVALIDPARAMETER_FILEURLINVALID = 'InvalidParameter.FileURLInvalid'

# 无效的文件格式
INVALIDPARAMETER_INVALIDFILEFORMAT = 'InvalidParameter.InvalidFileFormat'

# 无效的文件类型
INVALIDPARAMETER_INVALIDFILETYPE = 'InvalidParameter.InvalidFileType'

# 参数值错误。
INVALIDPARAMETERVALUE_INVALIDPARAMETERVALUELIMIT = 'InvalidParameterValue.InvalidParameterValueLimit'

# 超过最大文件页数限制
LIMITEXCEEDED_EXCEEDEDMAXPAGESERROR = 'LimitExceeded.ExceededMaxPagesError'

# 文件太大
LIMITEXCEEDED_TOOLARGEFILEERROR = 'LimitExceeded.TooLargeFileError'

# 请求的次数超过了频率限制。
REQUESTLIMITEXCEEDED = 'RequestLimitExceeded'

# 账号已欠费。
RESOURCEUNAVAILABLE_INARREARS = 'ResourceUnavailable.InArrears'

# 账号资源包耗尽。
RESOURCEUNAVAILABLE_RESOURCEPACKAGERUNOUT = 'ResourceUnavailable.ResourcePackageRunOut'

# 计费状态异常。
RESOURCESSOLDOUT_CHARGESTATUSEXCEPTION = 'ResourcesSoldOut.ChargeStatusException'
